import os
import logging

def log_level():
    if os.getenv('LT_SDK_DEBUG') == 'true':
        return logging.DEBUG 
    else:
        log_level_str = os.getenv('LT_SDK_LOG_LEVEL', 'info').lower()
        if log_level_str == 'debug':
            return logging.DEBUG
        elif log_level_str == 'warning':
            return logging.WARNING
        elif log_level_str == 'error':
            return logging.ERROR
        elif log_level_str == 'critical':
            return logging.CRITICAL
        else:
            return logging.INFO 
        

def setup_logger():
    logging.basicConfig(level=log_level())

def get_logger(package_name):
    logger = logging.getLogger(package_name)
    return logger



from lambdatest_sdk_utils.constants import get_smart_ui_server_address
from lambdatest_sdk_utils.logger import log_level,setup_logger,get_logger
from lambdatest_sdk_utils.rest import post_snapshot,is_smartui_enabled,fetch_dom_serializer
from lambdatest_sdk_utils.version import __version__


import requests
from lambdatest_sdk_utils.constants import get_smart_ui_server_address
from lambdatest_sdk_utils.logger import get_logger

logger = get_logger('lambdatest_sdk_utils')

def is_smartui_enabled():
    try:
        response = requests.get(f'{get_smart_ui_server_address()}/healthcheck')
        response.raise_for_status()
        return True
    except Exception as e:
        return False
    

def fetch_dom_serializer():
    try:
        response = requests.get(f'{get_smart_ui_server_address()}/domserializer')
        response.raise_for_status()
        return response.json()
    except requests.exceptions.HTTPError as e:
        err_resp = e.response.json()
        msg = err_resp.get('data', {}).get('error', 'Unknown error')
        logger.debug(f'fetch DOMSerializer API failed - {msg}')
        raise Exception(f'fetch DOMSerializer failed')
    except Exception as e:
        logger.debug(f'fetch DOMSerializer failed - {e}')
        raise Exception(f'fetch DOMSerializer failed')


def post_snapshot(snapshot,pkg,**kwargs):
    try:
        response = requests.post(f'{get_smart_ui_server_address()}/snapshot', json={
            'snapshot': {
                'dom' : snapshot['dom'],
                'name' : snapshot['name'],
                'url' : snapshot['url'],
                **kwargs
            },
            'testType': pkg
        })    
        response.raise_for_status()
        return response.json()
    except requests.exceptions.HTTPError as e:
        err_resp = e.response.json()
        msg = err_resp.get('data', {}).get('error', 'Unknown error')
        logger.debug(f'Snapshot Error: {msg}')
        raise Exception(f'Snapshot Error')
    except Exception as e:
        logger.debug(f'post snapshot failed : {msg}')
        raise Exception(f'post snapshot failed')





import os

def get_smart_ui_server_address():
    if not os.getenv('SMARTUI_SERVER_ADDRESS'):
        raise Exception('SmartUI server address not found')
    return os.getenv('SMARTUI_SERVER_ADDRESS')





from setuptools import setup, find_packages
import lambdatest_sdk_utils

setup(
    name="lambdatest-sdk-utils",
    version="1.0.2",
    author="LambdaTest <keys@lambdatest.com>",
    description="SDK utils",
    long_description="SDK utils for lambdatest",
    long_description_content_type="text/markdown",
    url="https://github.com/LambdaTest/lambdatest-python-sdk",
    keywords="lambdatest python selenium sdk",
    packages=find_packages(),
    license="MIT",
    install_requires=[
        "requests==2.*",
    ],
    python_requires='>=3.6',
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Programming Language :: Python :: 3",
        "Natural Language :: English",
        "License :: OSI Approved :: MIT License",
    ],
)
